var structkv_watch_options =
[
    [ "IgnoreDeletes", "structkv_watch_options.html#a0535edd21b26affc0057575bafc21a07", null ],
    [ "IncludeHistory", "structkv_watch_options.html#a08274f08ae96e14d9ded326e4e665649", null ],
    [ "MetaOnly", "structkv_watch_options.html#ac9094bce4f3c6513431ba32fb49e5605", null ],
    [ "Timeout", "structkv_watch_options.html#a56183d56585697d058c7eeb20bdddb66", null ],
    [ "UpdatesOnly", "structkv_watch_options.html#a82cd6bcb7167e7f798b6f912c1fa29c9", null ]
];